function [X,Y] = axbyc(A,B,C)
%AXBYC  Matrix 2-D polynomial equation solver
%
% The command
%    [X,Y] = AXBYC(A,B) 
% looks for a particular solution (X0,Y0) of the matrix polynomial Diophantine 
% equation        
%      AX + BY = C
%
% Parameters A,B,C has to be 2-D polynomial matrices (class POL2)
% The same class is the result X,Y



% fast check
if nargin < 3,
 error('Not enough input arguments.');
elseif nargin > 3,
 error('Too many input arguments.');
end;

A=pol2(A);
B=pol2(B);
C=pol2(C);

[rA,cA] = size(A);
[rB,cB] = size(B);
[rC,cC] = size(C); 

if (rA~=rB) | (rA~=rC),
 error('Matrices of inconsistent dimensions.');
end;

if ~all(A.d>=B.d),
    error('Noncausal system.');
end;

if ~all(C.d>=(2*A.d-[1,1])),
    error('Insufficient degree of C.');
end;
%----------------------------

%  parameter estimation

Xd=C.d-A.d; Yd=Xd;

A_sylv=sylv(A,Xd+[1,1],['x','y'],'col');
B_sylv=sylv(B,Xd+[1,1],['x','y'],'col');




% C1=sylv(A,B.d+[1,1],['x','y'],'col')*sylv(B,[1,1],['x','y'],'col');