function Q = deriv(P,varargin)
%DERIV     Derivative of 2-D polynomial
%
% Q = DERIV(P)            Valid when 2-D polynomial P
%                         depends on 'x' only or on 'y' only.
%                         Computes the derivative
%                           dP/dx  or  dP/dy .
% Q = DERIV(P,N)          Valid when P depends on 'x' only
%                         or on 'y' only. Computes the N-th
%                         derivative
%                           d^nP / dx^n  or  d^nP / dy^n
% Q = DERIV(P,N,M)        Computes the {N+M)-th derivative
%                           d^(n+m)P / dx^n dy^m
% Q = DERIV(P,M,N,'all')  Computes all derivatives from
%                         (0,0)-th to (M,N)-th.
%                         The result is a cell matrix.

eval('P = pol2(P);','error(peel(lasterr));');
n = []; m = []; allder = 0; err = 0;

li = length(varargin);
if li>0,
   for i = 1:li,
      arg = varargin{i};
      if isa(arg,'double'),
         if length(arg)==1 & isreal(arg) & arg>=0 & floor(arg)==arg,
         else err = 1;
         end;
         if isempty(n), n = arg;
         elseif isempty(m), m = arg;
         else err = 1;
         end;
      elseif isa(arg,'char'),
         if strcmp(arg,'all'), allder = 1;
         else err = 1;
         end;
      else err = 1;
      end;
      if err,
         text = ['Invalid ',nth(i+1),' argument.'];
         error(text);
      end;
   end;
end;

Pd = P.d;
if isempty(n),
   if isempty(Pd) | ~all(Pd>0),
      n = 1; m = 0;
   else err = 1;
   end;
elseif isempty(m),
   if isempty(Pd) | Pd(2)<=0,
   elseif Pd(1)<=0, m = n; n = 0;
   else err = 1;
   end;   
end;
if err, error('Not enough input arguments.');
end;

numbx = []; numby = [];
if isempty(Pd) | any(Pd<0),
else
   Ps = P.s; Ps1 = Ps(1); Ps2 = Ps(2);
   Pd1 = Pd(1); Pd2 = Pd(2);
   if n>0,
      numbx = 1:Pd1;
      numbx = kron(numbx,ones(Ps));
      numbx = reshape(numbx,Ps1,Ps2,Pd1);
      numbx = repmat(numbx,[1,1,1,Pd2+1]);
   end;
   if m>0,
      numby = 1:Pd2;
      numby = kron(numby,ones(Ps));
      numby = reshape(numby,Ps1,Ps2,1,Pd2);
      numby = repmat(numby,[1,1,Pd1+1,1]);
   end;
end;

if ~allder,
   Q = P;
   if n>0,
      for i = 1:n,
         Q = derivx(Q,numbx);
      end;
   end;
   if m>0,
      for i = 1:m,
         Q = derivy(Q,numby);
      end;
   end;
   
else
   Q = cell(n+1,m+1);
   Q{1,1} = P;
   if n>0,
      for i = 1:n,
         Q{i+1,1} = derivx(Q{i,1},numbx);
      end;
   end;
   if m>0,
      for j = 1:m,
         for i = 1:n+1,
            Q{i,j+1} = derivy(Q{i,j},numby);
         end;
      end;
   end;
end;
      
function G = derivx(F,numbx)

G = F;
Fd = F.d;
if isempty(Fd) | any(Fd<0), return;
end;
Fd1 = Fd(1); Fd2 = Fd(2);
G.c = F.c(:,:,2:Fd1+1,:).*numbx(:,:,1:Fd1,1:Fd2+1);
G.d(1) = Fd1-1;
if G.d(1)<0, G.d(1) = -Inf;
end;
G = pclear(G);

%end .. derivx

function G = derivy(F,numby)

G = F;
Fd = F.d;
if isempty(Fd) | any(Fd<0), return;
end;
Fd1 = Fd(1); Fd2 = Fd(2);
G.c = F.c(:,:,:,2:Fd2+1).*numby(:,:,1:Fd1+1,1:Fd2);
G.d(2)= Fd2-1;
if G.d(2)<0, G.d(2) = -Inf;
end;
G = pclear(G);

%end .. derivy

%end .. @pol2/deriv
