function Q = derivs(P,varargin)
%DERIVS    Derivatives of 2-D polynomial
%
% Q = DERIVS(P)          Computes the derivatives
%                        of 2-D polynomial P :
%                           dP/dx , dP/dy
%                        The result is a cell vector.
% Q = DERIVS(P,N)        Computes the N-th derivatives
%                           d^nP/dx^n ... d^nP/dy^n
% Q = DERIVS(P,N,'all')  Computes all derivatives
%                        from 0-th to N-th .
%                        The result ie a cell vector
%                        of cell vectors.

eval('P = pol2(P);','error(peel(lasterr));');
n = []; allder = 0; err = 0;

li = length(varargin);
if li>0,
   for i = 1:li,
      arg = varargin{i};
      if isa(arg,'double'),
         if length(arg)==1 & isreal(arg) & arg>=0 & floor(arg)==arg,
         else err = 1;
         end;
         if isempty(n), n = arg;
         else err = 1;
         end;
      elseif isa(arg,'char'),
         if strcmp(arg,'all'), allder = 1;
         else err = 1;
         end;
      else err = 1;
      end;
      if err,
         text = ['Invalid ',nth(i+1),' argument.'];
         error(text);
      end;
   end;
end;

if isempty(n), n = 1;
end;

numbx = []; numby = []; Pd = P.d;
if isempty(Pd) | any(Pd<0),
else
   Ps = P.s; Ps1 = Ps(1); Ps2 = Ps(2);
   Pd1 = Pd(1); Pd2 = Pd(2);
   if n>0,
      numbx = 1:Pd1;
      numbx = kron(numbx,ones(Ps));
      numbx = reshape(numbx,Ps1,Ps2,Pd1);
      numbx = repmat(numbx,[1,1,1,Pd2+1]);
      numby = 1:Pd2;
      numby = kron(numby,ones(Ps));
      numby = reshape(numby,Ps1,Ps2,1,Pd2);
      numby = repmat(numby,[1,1,Pd1+1,1]);
   end;
end;

R = cell(1,1); R{1} = P;
if allder,
   Q = cell(1,n+1); Q{1} = R;
end;
if n>0,
   for i = 2:n+1,
      S = cell(1,i);
      S{1} = derivx(R{1},numbx);
      for j = 2:i,
         S{j} = derivy(R{j-1},numby);
      end;
      if allder, Q{i} = S;
      end;
      R = S;
   end;
end;
if ~allder, Q = R;
end;

function G = derivx(F,numbx)

G = F;
Fd = F.d;
if isempty(Fd) | any(Fd<0), return;
end;
Fd1 = Fd(1); Fd2 = Fd(2);
G.c = F.c(:,:,2:Fd1+1,:).*numbx(:,:,1:Fd1,1:Fd2+1);
G.d(1) = Fd1-1;
if G.d(1)<0, G.d(1) = -Inf;
end;
G = pclear(G);

%end .. derivx

function G = derivy(F,numby)

G = F;
Fd = F.d;
if isempty(Fd) | any(Fd<0), return;
end;
Fd1 = Fd(1); Fd2 = Fd(2);
G.c = F.c(:,:,:,2:Fd2+1).*numby(:,:,1:Fd1+1,1:Fd2);
G.d(2)= Fd2-1;
if G.d(2)<0, G.d(2) = -Inf;
end;
G = pclear(G);

%end .. derivy

%end .. @pol2/derivs

      