function D = diag(A,k);
%DIAG  Diagonal matrix or diagonal of 2-D polynomial
%
% Let Av be a 2-D polynomial vector with N components. Then
%    DIAG(Av,K)  
% is a square 2-D polynomial matrix of dimensions (N+ABS(K))-by-(N+ABS(K))
% with the elements of Av on the K-th diagonal. K = 0 is the main diagonal, 
% K > 0 is above the main diagonal, and K < 0 is below the main diagonal.
% DIAG(Av) is the same as DIAG(Av,0).
%
% Let Am be a 2-D polynomial matrix. Then
%    DIAG(Am,K)  
% is a column 2-D polynomial vector formed from the elements of the K-th 
% diagonal of Am. DIAG(Am) is the main diagonal of Am. 
%
% DIAG(DIAG(Am)) is a diagonal matrix.
%

if nargin == 1, k = 0;
elseif ~isa(k,'double') | length(k)~=1 | ~isreal(k) | round(k)~=k,
   error('Invalid 2nd argument; must be scalar integer.');
end;

Ac = A.c; Ad = A.d;
%An1 = Ad(1)+1; An2 = Ad(2)+1;
D.d = Ad; Dc = [];
eval('Dc = diag(zeros(A.s(1),A.s(2)),k);','error(lasterr);');
D.s = size(Dc);
if ~isempty(Dc),
   An1 = Ad(1)+1; An2 = Ad(2)+1;
   if An1>1 & An2>1,
      Dc = repmat(Dc,[1,1,An1,An2]);
   end;
   sw = warning; warning off;
   for i = 1:An1,
      for j = 1:An2,
         Dc(:,:,i,j) = diag(Ac(:,:,i,j),k);
      end;
   end;
   warning(sw);
else D.d = [];
end;
D.c = Dc;
D.v = A.v;
D.u = [];
D = class(D,'pol2');
D = pclear(D);

%end .. @pol2/diag
