function F_flipped = flipcoef(varargin);

% The function 
% F = FLIPCOEF (A,var)
% flip just the coefficient vector respecting the degree and
% other 2-D polynomial properties
% 
% var - is a parameter to specify for which variable is to perform the flip
%     - calling F=FLIPCOEF(A)  no variable is explicitly specified so the
%       flip is performend in both variables x and y 
%     - calling F=FLIPCOEF(A,'x') the flip is performed just in the
%       direction of the variable x
%     - calling F=FLIPCOEF(A,'y') the flip is performed just in the
%       direction of the variable y
% 
% example
%  A =     7   + 10*x     + 20*x^2     + 30*x^3  +
%      +   y   + 11*x*y   + 21*x^2*y   + 31*x^3*y +
%      + 2*y^2 + 12*x*y^2 + 22*x^2*y^2 + 32*x^3*y^2
%
%  A_flipped_x = FLIPCOEF(A,'x')
%          returns
%  A_flipped_x =       30   +  20*x    + 10*x^2     + 7*x^3  +
%                +   31*y   + 21*x*y   + 21*x^2*y   +   x^3*y +
%                +   32*y^2 + 22*x*y^2 + 12*x^2*y^2 + 2*x^3*y^2
% 
%  A_flipped_y = FLIPCOEF(A,'y')
%          returns
%  A_flipped_y  =     2   + 12*x     + 22*x^2     + 32*x^3  +
%                 +   y   + 11*x*y   + 21*x^2*y   + 31*x^3*y +
%                 + 7*y^2 + 10*x*y^2 + 20*x^2*y^2 + 30*x^3*y^2
%
%  A_flipped = FLIPCOEF(A)
%          returns
%  A_flipped  =     32    + 22*x     + 12*x^2     +  2*x^3  +
%                + 31*y   + 21*x*y   + 11*x^2*y   +    x^3*y +
%                + 32*y^2 + 20*x*y^2 + 10*x^2*y^2 +  7*x^3*y^2
%
% Note that for 
% A=55*x^5*y^5 or all other single-coefficient polynomials the result is 
% A_flipped = 55
%
%  have a nice day :)

% fast check
 if ~isa(varargin{1},'pol2'),
     error('Wrong argument class. POL2 needed.');
 end;

% choose parameters
if nargin==1,
    parameter2='all';
elseif nargin==2,
    if ~(varargin{2}=='x' | varargin{2}=='y'),
        error('Only ''x'' or ''y'' allowed as explicite 2nd argument.');
    end;
    parameter2=varargin{2};
elseif nargin>2,
   error('Too many input arguments.');
end;

% perform flip
F_flipped=varargin{1};
dgrs=F_flipped.d;     %each degrees in [x,y]
if (parameter2 == 'all' | parameter2 == 'x'),  % flip in variable x
    max_x=dgrs(1)+1;
    F_flipped.c=F_flipped.c(:,:,max_x:-1:1,:);
end;
if (parameter2 == 'all' | parameter2 == 'y'),  % flip in variable y
    max_y=dgrs(2)+1;
    F_flipped.c=F_flipped.c(:,:,:,max_y:-1:1);
end;

F_flipped=pclear(F_flipped);

% end pol2/flicoef
    
