function Z = mvalue(F,X,Y)
%MVALUE     Matrix value of 2-D polynomial
%
% The command  Z = MVALUE(F,X,Y)  returns value F(X,Y)
% of 2-D polynomial function F of the arguments X and Y.
%
% If F is scalar 2-D polynomial then one of X,Y may be square
% matrix; the other must be scalar. If F is not scalar then
% both X and Y mst be scalars.
%
% When F is a function of X only, the argument Y plays
% no role. It may be any scalar or any square matrix
% or it may be omitted. Similarly, when F is a function
% of Y only, the argument X may be omitted. When F is
% empty or constant, both X and Y may be omitted.
%
% Matrices X,Y or some entries of them may be infinite.

ni = nargin;
if ni>=2,
   if ~isa(X,'double') | ndims(X)>2,
      error('Invalid 2nd argument.');
   end;
end;
if ni==3,
   if ~isa(Y,'double') | ndims(Y)>2,
      error('Invalid 3rd argument.');
   end;
end;

sF = size(F); Fd = F.d;
if all(size(F)==[1 1]),
   if ni>=2,
      sX = size(X);
      if sX(1)~=sX(2),
         error('Invalid 2nd argument; must be square matrix.');
      end;
      if ni==3,
         sY = size(Y);
         if sX(1)~=1,
            if any(sY~=[1 1]),
               if any(sX~=sY),
                  error('Matrices not of the same dimensions.');
               end;
               if any(any(X*Y~=Y*X)) & ~isempty(Fd) & all(Fd>=1),
                  Fc = F.c(1,1,2:end,2:end);
                  if any(any(Fc~=0)),
                     error('Matrices are not commutative.');
                  end;
               end;
            end;
         else
            if sY(1)~=sY(2),
               error('Invalid 3rd argument; must be square matrix.');
            end;
         end;
      end;
   end;
   
else
   if ni>=2,
      sX = size(X);
      if any(sX~=[1 1]),
         error('Invalid 2nd argument; must be scalar.');
      end;
      if ni==3,
         sY = size(Y);
         if any(sY~=[1 1]),
            error('Invalid 3rd argument; must be scalar.');
         end;
      end;
   end;
end;

Z = zeros(sF);
if any(sF==0), return;
end;

if any(Fd<0),
   if ni>=2,
      if sX(1)~=1, Z = zeros(sX);
      end;
      if ni==3,
         if sY(1)~=1, Z = zeros(sY);
         end;
      end;
   end;
   return;
end;

I = 1;
if ni>=2,
   if sX(1)~=1, I = eye(sX);
   end;
   if ni==3,
      if sY(1)~=1, I = eye(sY);
      end;
   end;
end;   

Fd1 = Fd(1); Fd2 = Fd(2);
Z = F.c(:,:,Fd1+1,Fd2+1)*I;
if Fd2>0,
   if ni==2, Y = X;
   elseif ni==1,
      error('Not enough input arguments.');
   end;
   for l = Fd2:-1:1,
      Z = Z*Y + F.c(:,:,Fd1+1,1)*I;
   end;
end;
if Fd1>0,
   for k = Fd1:-1:1,
      G = F.c(:,:,k,Fd2+1)*I;
      if ni==1,
         error('Not enough input arguments.');
      end;
      if Fd2>0,
         if ni==2,
            error('Not enough input aguments.');
         end;
         for l = Fd2:-1:1,
            G = G*Y + F.c(:,:,k,l)*I;
         end;
      end;
      Z = Z*X + G;
   end;
end;
   
%end .. @pol2/mvalue
   