function A = sum(P,dim);
%SUM   Element-wise sum of 2-D polynomial
% 
% For a 2-D polynomial vector P (i.e., a 2-Dpolynomial matrix with one row
% or one column)
%    SUM(P) 
% is the sum of the elements of P. 
%
% For other 2-D polynomial matrices, SUM(P) is a row vector with the sum 
% over each column. 
%
% SUM(X,DIM) sums along the dimension DIM, where DIM is 1 or 2.
%

if nargin==1, dim = [];
end;

Pc = P.c; 
Psi = P.s; 
Pd = P.d;

if isempty(dim),
   if isempty(Pd),
      A = pol2(sum(zeros(Psi)));
      return;
   end;
   dim = find(Psi~=1);
   if isempty(dim),
      dim = 1;
   else
      dim = dim(1);
   end;
end;
if ~isa(dim,'double') | length(dim)~=1 |(dim~=1 & dim~=2),
   error('Invalid dimension.');
end;

if isempty(Pd) | isinf(Pd),
  A = pol2(sum(zeros(Psi),dim));
  return;
end;

Ac = sum(P.c,dim);
A.d = Pd;
A.s = [size(Ac,1) size(Ac,2)];
A.c = Ac;
A.v = P.v;
A.u = [];

A = class(A,'pol2');
A = pclear(A);

%end .. @pol2/sum
