function M=sylv(varargin);
% The function
%   M=SYLV(A,K,VAR,STRING)
% reshape the 2-D polynomial matrix
% into a row or column block-matrix
% folowing the increase degrees in 
% choosen variables.
% 
%   If 
%          A = A0 + A1(x)*y + A2(x)*y^2 + ... + Ad(x)*y^d
%   then
%          S = [ A0 A1 A2 ... Ad  0  0  ...  0 |   block row 1.
%              | 0  A0 A1  A2 ... Ad 0  ...  0 |   block row 2.
%              | 0  0  ...    ... ...   ...  0 |   ...
%              | 0  0  ...    ... ...A0 ...  Ad]   block row K+1.
%  
%   The input argument K can be:
%   as default is taken the degree of the given variable
%   K - number of rows/columns 
%   K=[Kx,Ky] - separated block sizes in both variables
%               Is Kx,Ky < 1 then Kx,Ky =1
%
%   The input argument VAR can be:
%   'x' or missing - the resulting matrix S is depend by varible 'y'
%   'y' - the resulting matrix S is depend by varible 'y'
%   ['y','x'] - the resulting matrix S contain blocks of matrices
%               is the parameter K=[Ky,Kx] missing the degrees in the
%               right order are taken
%   ['x','y'] - optional/default by given K=[Kx,Ky]
%
%   The input argument STRING can be:
%   'row' or missing - row Sylvester matrix
%   'col' - column Sylvester matrix
%


% Extract & SET 
n=nargin;
if n<1 | n>4,
    error ('Wrong argument number.');
end;

input_arg=cell(1,4);
input_arg(1:n)=varargin(1:n);
clear varargin;
% setting & checking
% ---- POL2 matrix ----
if ~isa(input_arg{1},'POL2'),
    error('Wrong 1st argument. This SYLV function works with POL2 objects only.');
end;
% ---- Degrees --------
if isempty(input_arg{2}),
    if isempty(input_arg{3}),
        input_arg{2}=input_arg{1}.d;
    elseif input_arg{3}=='x',
        input_arg{2}=input_arg{1}.d(1);
    elseif input_arg{3}=='y',
        input_arg{2}=input_arg{1}.d(2);
    elseif input_arg{3}==['x','y'],
        input_arg{2}=input_arg{1}.d;
    elseif input_arg{3}==['y','x'],
        input_arg{2}=fliplr(input_arg{1}.d);
    end;
elseif ~isa(input_arg{2},'double'),
    error('The 2nd input argument has to be a DOUBLE vector.');
elseif ~(size(input_arg{2})==[1,2] | size(input_arg{2})==[1,1]),
    error('The 2nd input argument has a wrong dimension. ');
else
    input_arg{2}=floor(input_arg{2});
end;
% ---- Variable succession ----
if isempty(input_arg{3}) & size(input_arg{2})==[1,2],
    input_arg{3}=['x','y'];
elseif isempty(input_arg{3}) & size(input_arg{2})==[1,1],
    input_arg{3}='x';
elseif input_arg{3}=='y' & size(input_arg{2})==[1,2],
    input_arg{3}=['y','x'];
elseif ~isa(input_arg{3},'char');
    error('The 3rd input argument has to be a char');
elseif size(input_arg{3})>=3,
    error('The 3rd input argument is to large.')
end;
% dodelat 
if size(input_arg{3})~=size(input_arg{2}),
    error('Variable mishmash between the 2nd and 3rd argument.');
end;
% ---- row / column ----
if isempty(input_arg{4}),
    input_arg{4}='row';
elseif ~(input_arg{4}=='row' | input_arg{4}=='col'),
    error('The 4th argument is invalid.');
end;
%---------------------------
K=input_arg{2};
% row/column assembling
if input_arg{4}=='col';
    input_arg{1}.c=permute(input_arg{1}.c,[2 1 3 4]); % for column vectors 
end;
if input_arg{3}(1)=='y',
    input_arg{1}.c=(permute(input_arg{1}.c,[1 2 4 3]));
end;
for var_indx=1:length(input_arg{3}),
    % --- (nonzero) row/column assembling ---
    Ac1=size(input_arg{1}.c,1);
    Ac2=size(input_arg{1}.c,2);
    
    Sylv_vctr=reshape(input_arg{1}.c,[Ac1,Ac2*size(input_arg{1}.c,3),size(input_arg{1}.c,4)]); % prepared sylvester vector - 1 strip
    % generelly 3-D matrix
    %---- pad with zeros matrices of vectros in a sylv matrix ------
    if K(var_indx)<1,
        K(var_indx)=1;
    end;
    S_row=Ac1*K(var_indx); %how many rows the final Sylvester sub-matrix in this variable needs
    S_col=Ac2*(size(input_arg{1}.c,3)+K(var_indx)-1); % how many columns
    
    input_arg{1}.c=zeros(S_row,S_col,size(input_arg{1}.c,4));
    % Sylvester matrix filling - generator of shift indexes
    for shift_indx=0:K(var_indx)-1,
        rl=shift_indx*Ac1+1;
        rh=rl+size(Sylv_vctr,1)-1;
        cl=shift_indx*Ac2+1;
        ch=cl+size(Sylv_vctr,2)-1;
        % ---!!!!!---
        input_arg{1}.c(rl:rh,cl:ch,:)=Sylv_vctr;
    end;
    %----------------------------------------------------------------
    
%     Ac=permute(Ac,[1 2 4 3]); % swap ever back
end;  %  for var_indx=1:length(Var),
 
if input_arg{4}=='col',
    input_arg{1}.c=permute(input_arg{1}.c,[2 1 3 4]); % for column vectors 
end;

% Output preparing

if input_arg{3}=='y',
    M=pol2(input_arg{1}.c,'x');
elseif input_arg{3}=='x',
    M=pol2(input_arg{1}.c,'y');
elseif input_arg{3}==['x','y'] | input_arg{3}==['y','x'],
    M=input_arg{1}.c;
else
    error('Sorry, something is wrong. :))')
end;
    