function C=minus(A,B);

%MINUS  Subtraction of two POL2SP-matrices:
%            C = A - B
%
% The commands
%    C = A - B
%    C = MINUS(A,B) 
% subtract the POL2SP-matrix B from A.
%
% See also PLUS, UMINUS.


if nargin < 2,
   error('Incorrect number of inputs.');
elseif nargout > 1,
   error('Incorrect number of outputs.');
end;

A=pol2sp(A);
B=pol2sp(B);

if all(size(A)==[1,1]),
    Bs=B.s
    A=repmat(A,Bs(1),Bs(2));    
elseif all(size(B)==[1,1]),
    As=A.s
    B=repmat(B,As(1),As(2));    
elseif (A.s ~= B.s),
   error ('Inner matrix dimensions must agree.');
end;

if (A.n~=B.n),
   [A,B]=msl(A,B);
end;



C.d = max([A.d;B.d],[],1);  % separate degree entry for each variable
C.n = A.n;  % number of used spectra-points
C.s = A.s; % size of matrix
C.c = A.c-B.c; 
C.v = ['x','y'];
C.u = [];
C.k = A.k & B.k;

C=class(C,'pol2sp');
