function P = mpower(A,n);
%MPOWER   Matrix power of 2-D polynomial-spectra
%
% P=MPOWER(A,n) or P=A^n
% compute the n-th power of the 2-D polynomial matrix
% A - POL2SP-class 2-D polynomial matrix (square)
% n - nonnegative integer exponent

if nargin<2,
   error('Not enough input arguments.');
end;
if ~isa(n,'double') | ndims(n)>2 | ~isreal(n) | ...
      (~isempty(n) & (any(any(n<0)) | any(any(floor(n)~=n)))),
   error('Invalid power; must be nonnegative integer.');
end;

if ~isa(A,'POL2SP'),
   error('Matrix is not POL2SP object.');
elseif size(A)~=fliplr(size(A));
    error('Matrix is not square.');
end;

if n>1,
    A=msl(A,(A.n).*n);
    P.d = A.d*n;  % separate degree entry for each variable
    P.n = A.n;  % number of used spectra-points
    P.s = A.s; % size of matrix
    P.c = zeros(size(A.c)); % 
    P.v = ['x','y'];
    P.u = [];
    P.k = A.k;
    
    nA=A.n;
    
    for nX=1:nA(1),
        for nY=1:nA(2),
            P.c(:,:,nX,nY)=(A.c(:,:,nX,nY))^n;
        end;
    end;
    P=class(P,'pol2sp');
    
elseif n==1,
    P=A;
elseif n==0,
    P.d = [0,0];  % separate degree entry for each variable
    P.n = [1,1];  % number of used spectra-points
    P.s = A.s; % size of matrix
    Asize=size(A);
    P.c = diag(ones(1,Asize(2))); % 
    P.v = ['x','y'];
    P.u = [];
    P.k = isreal(P.c);
    P=class(P,'pol2sp');
else
    error('Something is wrong :))');
end;  % if n>1,
    
    
    
