function C=times(A,B);
% FUNCTION A.*B solves the multiplication
% element-by-element POL2SP matrices A and B 

if nargin < 2,
   error('Incorrect number of inputs.');
elseif nargout > 1,
   error('Incorrect number of outputs.');
end;

A=pol2sp(A);
B=pol2sp(B);

if all(size(A)==[1,1]),
    Bs=B.s;
    A=repmat(A,Bs(1),Bs(2));    
elseif all(size(B)==[1,1]),
    As=A.s;
    B=repmat(B,As(1),As(2));    
elseif (A.s ~= B.s),
   error ('Inner matrix dimensions must agree.');
end;

Nsp=2.^(ceil(log2(A.d+B.d+[1,1])));
[A,B]=msl(A,B,Nsp);

C.d = A.d+B.d;  % separate degree entry for each variable
C.n = Nsp;  % number of used spectra-points
C.s = A.s; % size of matrix
C.c = (A.c).*(B.c); 
C.v = ['x','y'];
C.u = [];
C.k = A.k & B.k;

C=class(C,'pol2sp');
