function [xx,x] = fftspf2(p,N);
% Plus/minus factorization of two-sided scalar polynomial.
%
% [Qplus, Qminus] = FFTPLUSMINUS(P)
% 
% Qplus strictly stable, Qminus strictly unstable, Qplus*Qminus = P.

R = 2^N;


% variable options & roots at zero
var = p.v;
iszi = (strcmp(var,'z^-1') | strcmp(var,'d')) | strcmp(var,'zi');
if iszi
    indcs = find(logical(p.c));
    shft1 = indcs(1)-1;    
    p = shift(p,-shft1);
    p = reverse(p);
    p.v = 'z';
else
    indcs = find(logical(p.c));
    shft1 = indcs(1)-1;    
    p = shift(p,-shft1);
end;

degp =  p.d;
pc = p.c;

if degp~=0,

% Find shift - angle crosses +/-pi
% M = fft(pc,R);
% x = imag(M)>0;
% y = diff(x);
% y(:,:,R) = x(end)-x(1);
% rMneg = real(M)<0;
% n1 = find((y==1) & (rMneg));
% n2 = find((y==-1) & (rMneg));
% shft = length(n1)-length(n2)

% Find shift - number of unstable zeros - via Schur
% shft = zeroscnt(p)
pc = p.c;
d = pc(:).';
c = fliplr(d);
D = zeros(1,degp-1);
cnt = 0;
for i=1:p.d
    cpiv =  c(1);
    dpiv = d(1);
    c = cpiv*d(2:end) - dpiv*c(2:end);
    d = c(end:-1:1);
    c = c./norm(c);
    d = d./norm(d);
    D(i) = d(1);
end;
P = zeros(1,degp);
sgnD = sign(D);
P(1) = -sgnD(1);
for i = 2:degp,
    P(i) = -1*sgnD(i)*sign(P(i-1));
end;
shft = length(find(P<0));

% Perform shift and continue as with FFTSPF
pc = cat(3, pc(:,:,shft+1:end), zeros(1,1,R-length(pc)), pc(:,:,1:shft));
M = fft(pc,R);
N = log(M);
difN = diff(imag(N));

indcs = find(abs(difN-2*pi)<1);
for i=indcs,
    N(i+1:end) = N(i+1:end) - j*2*pi;
end;

indcs = find(abs(difN+2*pi)<1);
for i=indcs,
    N(i+1:end) = N(i+1:end) + j*2*pi;
end;

n = ifft(N);

y = cat(3, n(1)/2, n(2:R/2) );
yy = cat(3, n(1)/2, n(R:-1:R/2+1) );

Y = fft(y, R);
X = exp(Y);

YY = fft(yy, R);
XX = exp(YY);

x = ifft(X);
xx = ifft(XX);

degx = degp-shft;
x = x(:).';
x = x./x(1)*p{0}; x = real(x);
x = pol(x(1:degx+1),degx,'z');

degxx = shft;
xx = xx(:).';
xx = xx./xx(degxx+1); xx = real(xx);
xx = pol(xx(degxx+1:-1:1),degxx,'z');


else %if degp~=0
    
x = 1;
xx = 1;

end; %if degp~=0

if iszi
    x = reverse(x);
    x = shift(x,shft1);x.v = var;
    xx = reverse(xx);xx.v = var;
else
    xx = shift(xx,shft1);
    xx.v = var;
end;