function Astar = tsp2adj(A)

% The function
%    X = TSP2ADJ (A)
% perform the adjoint of the (real or complex) two-sided 2-D polynomial
% like follows (where X=F*)
%
% F*(z1,z2)=conj(F(conj(z1^-1),conj(z2^-1)))   - for complex polynomials
%  or 
% F*(z1,z2)=F(z1^-1,z2^-1)                     - for the real case
%
% example (in tsp2 notation)
%  A = u*w+3*w^2+4*u^4
%  X=tsp2adj(A)
%  X = u^-1*w^-1+3*w^-2+4*u^-4

% fast check
 if ~isa(A,'tsp2'),
     error('Wrong argument class. TSP2 needed.');
 end;
%------------------
% nereseno pro maticovy pripad - zatim pouze pro skalary

ad=A.d;  %the degree-vector of the origin
ao=A.o;  %the offset-vector of the origin

Astar.p=conj(flipcoef(A.p));
Astar.s = A.s;
Astar.d = A.d;            % tak zde si nejsem jisty, ale asi jo
Astar.o = -(A.d+A.o);          % tady pozor
Astar.v = 'uw';
Astar.u = ['created as adjointed two-sided 2-D polynomial'];

Astar = class(Astar,'tsp2');
Astar = tclear(Astar);

% end    @tsp2\tsp2adj